#!/usr/bin/python3

import bme280
import smbus2
from time import sleep
import math

port = 1
address = 0x76 # Adafruit BME280 address. Other BME280s may be different
bus = smbus2.SMBus(port)

def truncate(n, decimals=0):
    multiplier = 10 ** decimals
    return int(n * multiplier) / multiplier

def get_frost_point_c(t_air_c, dew_point_c):
    dew_point_k = 273.15 + dew_point_c
    t_air_k = 273.15 + t_air_c
    frost_point_k = dew_point_k - t_air_k + 2671.02 / ((2954.61 / t_air_k) + 2.193665 * math.log(t_air_k) - 13.3448)
    return frost_point_k - 273.15

def get_dew_point_c(t_air_c, rel_humidity):
    A = 17.27
    B = 237.7
    alpha = ((A * t_air_c) / (B + t_air_c)) + math.log(rel_humidity/100.0)
    return (B * alpha) / (A - alpha)

bme280.load_calibration_params(bus,address)
wxdata = bme280.sample(bus,address)
humidity  = wxdata.humidity
pressure  = wxdata.pressure
pressure_i = wxdata.pressure / 33.863886666667
temperature = wxdata.temperature
temperature_f = (wxdata.temperature * 1.8) + 32
dew_point = get_dew_point_c(wxdata.temperature, wxdata.humidity)
dew_point_f = (dew_point *1.8) + 32
h = round(humidity)
pm = truncate(pressure, 2)
pi = truncate(pressure_i, 2)
tc = truncate(temperature, 2)
tf = truncate(temperature_f, 2)
dp = truncate(dew_point, 2)
df = truncate(dew_point_f, 2)

pm = '%.2f' % pm
if len(pm) == 6:
    pm = ' ' + pm

print('║ Temperature  ║▒ ║   Humidity   ║▒ ║   Pressure   ║▒ ║  Dew Point   ║▒')
print('║              ║▒ ║              ║▒ ║              ║▒ ║              ║▒')
if h == 100:
    print('║   {0:.2f}°F    ║▒ ║     {1}%     ║▒ ║ {2} mbar ║▒ ║   {3:.2f}°F    ║▒'.format(tf, h, pm, df))
else:
    print('║   {0:.2f}°F    ║▒ ║     {1}%      ║▒ ║ {2} mbar ║▒ ║   {3:.2f}°F    ║▒'.format(tf, h, pm, df))
if int(tc) < 10 and int(dp) < 10:
    print('║    {0:.2f}°C    ║▒ ║              ║▒ ║  {1:.2f} inHg  ║▒ ║    {2:.2f}°C    ║▒'.format(tc, pi, dp))
elif int(tc) > 10 and int(dp) < 10:
    print('║   {0:.2f}°C    ║▒ ║              ║▒ ║  {1:.2f} inHg  ║▒ ║    {2:.2f}°C    ║▒'.format(tc, pi, dp))
else:
    print('║   {0:.2f}°C    ║▒ ║              ║▒ ║  {1:.2f} inHg  ║▒ ║   {2:.2f}°C    ║▒'.format(tc, pi, dp))
