#!/usr/bin/python3
import os
import sys
import bme280
import smbus2

port = 1
address = 0x76 # Adafruit BME280 address. Other BME280s may be different
bus = smbus2.SMBus(port)
bme280.load_calibration_params(bus,address)
wxdata = bme280.sample(bus,address)
temperature = wxdata.temperature
temperature_f = (wxdata.temperature * 1.8) + 32

# Initial variables set at impossible high or low temperatures
high_temp = -100
low_temp = 200
high_cel = -100
low_cel = 200

# 
def temp_process(s):
    sa = s.split()
    st = sa[1]
    stemp = st.replace('°F', '')
    return stemp

def cel_process(s):
    sa = s.split()
    st = sa[2]
    stemp = st.replace('°C', '')
    return stemp

def high(t, h):
    global high_temp
    if float(t) > high_temp:
        high_temp = float(t)
    else:
        pass

def low(t, l):
    global low_temp
    if float(t) < low_temp:
        low_temp = float(t)
    else:
        pass

def c_high(t, h):
    global high_cel
    if float(t) > high_cel:
        high_cel = float(t)
    else:
        pass

def c_low(t, l):
    global low_cel
    if float(t) < low_cel:
        low_cel = float(t)
    else:
        pass

def rain_file(file): 
    first = 26
    second = 10
    f1, f2 = file[:first], file[first:]
    s1, s2 = f2[:second], f2[second:]
    convert = f1 + "rain/" + s1 + "-rain" + s2
    return convert

def rain_calc(file):
    f = open(file, 'r')
    total = 0
    for i in f:
        sf = i.split()
        rf = sf[1]
        total = total + float(rf)
    return total

def rain_inch(m):
    inch = m * .0393701
    return inch

def spacer(s):
    length = len(s)
    space = 16 - length
    if space == 2:
        s = s + "  "
    elif space == 1:
        s = s + " "
    else:
        pass
    return s

def spacer_rain(s):
    length = len(s)
    space = 8 - length
    if space == 2:
        s = s + "  "
    elif space == 1:
        s = s + " "
    else:
        pass
    return s

def fixer(number):
    nt = str(number).split(".")
    if len(nt[1]) == 1:
        ns = str(number) + "0"
        return ns
    else:
        ns = str(number)
        return ns

log_file = sys.argv[-1]
rain = rain_file(log_file)
f = open(log_file, 'r')

for i in f:
    if i[0].isdigit():
        current = temp_process(i)
        cel = cel_process(i)
        high(current, high_temp)
        low(current, low_temp)
        c_high(cel, high_cel)
        c_low(cel, low_cel)
    else:
        pass

#tempf = fixer(round(high_temp, 2)) + "°F/" + str(low_temp) + "°F"
#tempc = fixer(round(high_cel, 2)) + "°C/" + str(low_cel) + "°C"
tempf = fixer(round(high_temp, 2)) + "°F/" + fixer(round(low_temp, 2)) + "°F"
tempc = fixer(round(high_cel, 2)) + "°C/" + fixer(round(low_cel, 2)) + "°C"
#print(spacer(tempc), "|")
#test = len(tempc)
#print(test)
rainm = fixer(round(rain_calc(rain), 2)) + "mm"
raini = fixer(round(rain_inch(rain_calc(rain)), 2)) + "in" 


print('║          Daily High/Low        ║▒ ║             Rainfall           ║▒') 
print('║                                ║▒ ║                                ║▒')
print('║         {0}       ║▒ ║             {1}           ║▒'.format(spacer(tempf), spacer_rain(raini)))
print('║         {0}       ║▒ ║             {1}           ║▒'.format(spacer(tempc), spacer_rain(rainm)))
