#!/usr/bin/python3

import bme280
import smbus2
import datetime
import os.path
from pathlib import Path
import math
import shutil

port = 1
address = 0x76 # Adafruit BME280 address. Other BME280s may be different
bus = smbus2.SMBus(port)
year = datetime.datetime.now().year
month = datetime.datetime.now().month
time = datetime.datetime.now().time()

def truncate(n, decimals=0):
    multiplier = 10 ** decimals
    return int(n * multiplier) / multiplier

def get_dew_point_c(t_air_c, rel_humidity):
    """Compute the dew point in degrees Celsius

    :param t_air_c: current ambient temperature in degrees Celsius
    :type t_air_c: float
    :param rel_humidity: relative humidity in %
    :type rel_humidity: float
    :return: the dew point in degrees Celsius
    :rtype: float
    """
    A = 17.27
    B = 237.7
    alpha = ((A * t_air_c) / (B + t_air_c)) + math.log(rel_humidity/100.0)
    return (B * alpha) / (A - alpha)

def entry():
    port = 1
    address = 0x76 # Adafruit BME280 address. Other BME280s may be different
    bus = smbus2.SMBus(port)
    bme280.load_calibration_params(bus,address)
    wxdata = bme280.sample(bus,address)
    humidity  = wxdata.humidity
    pressure  = wxdata.pressure
    pressure_i = wxdata.pressure / 33.863886666667
    temperature = wxdata.temperature
    temperature_f = (wxdata.temperature * 1.8) + 32
    dew_point = get_dew_point_c(wxdata.temperature, wxdata.humidity)
    dew_point_f = (dew_point * 1.8) +32
    h = round(humidity)
    pm = truncate(pressure, 2)
    pi = truncate(pressure_i, 2)
    tc = truncate(temperature, 2)
    tf = truncate(temperature_f, 2)
    dt_now = datetime.datetime.now()
    dt = dt_now.strftime("%H:%M:%S")
    dp = truncate(dew_point, 2)
    df = truncate(dew_point_f, 2)
    entry = '{0} {1:.2f}°F {2:.2f}°C {3}% {4:.2f}mbar {5:.2f}inHg {6:.2f}°F {7:.2f}°C\n'.format(dt, tf, tc, h, pm, pi, df, dp)
    return entry


def wx_log(y, m):
    if 1 <= m < 10:
        month = "0" + str(m)
    else:
        month = str(m)
    dir_path = "/var/gopher/wxlog/" + str(y) + "/" + month
    dir_path_rain = "/var/gopher/wxlog/" + str(y) + "/" + month + "/rain"
    if not os.path.exists(dir_path):
        os.makedirs(dir_path)
        os.makedirs(dir_path_rain)
        shutil.copy2('/var/gopher/skel/index.dcgi', dir_path)
        shutil.copy2('/var/gopher/skel/dp.dcgi', dir_path)
        shutil.copy2('/var/gopher/skel/hum.dcgi', dir_path)
        shutil.copy2('/var/gopher/skel/plot-d.dcgi', dir_path)
        shutil.copy2('/var/gopher/skel/plot-h.dcgi', dir_path)
        shutil.copy2('/var/gopher/skel/plot-p.dcgi', dir_path)
        shutil.copy2('/var/gopher/skel/plot-t.dcgi', dir_path)
        shutil.copy2('/var/gopher/skel/pres.dcgi', dir_path)
        shutil.copy2('/var/gopher/skel/temp.dcgi', dir_path)
        shutil.copy2('/var/gopher/skel/rtotals.dcgi', dir_path)
    file_name = str(datetime.datetime.now().date()) + ".txt"
    check_file = Path(dir_path + "/" + file_name)
    whole_path = dir_path + "/" + file_name
    if check_file.is_file():
        f = open(whole_path, 'a')
        f.write(entry())
    else:
        f = open(whole_path, 'a')
        f.write("WX Station perilo.us # Hernando, MS # " + str(datetime.datetime.now().date()) + "\n")
        f.write("------------------------------------------------------------------\n")
        f.write("   Time | Temperature | Humidity | Air Pressure | Dew Point\n")
        f.write("------------------------------------------------------------------\n")
        f.write(entry())

wx_log(year, month)
